Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1837)

Unified Diff: webkit/api/public/WebSearchableFormData.h

Issue 306057: Move SearchableFormData over to the WebKit API. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/render_view.cc ('k') | webkit/api/src/WebSearchableFormData.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/api/public/WebSearchableFormData.h
===================================================================
--- webkit/api/public/WebSearchableFormData.h (revision 29420)
+++ webkit/api/public/WebSearchableFormData.h (working copy)
@@ -1,46 +1,68 @@
-// Copyright (c) 2006-2008 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
+/*
+ * Copyright (C) 2009 Google Inc. All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ * * Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ * * Redistributions in binary form must reproduce the above
+ * copyright notice, this list of conditions and the following disclaimer
+ * in the documentation and/or other materials provided with the
+ * distribution.
+ * * Neither the name of Google Inc. nor the names of its
+ * contributors may be used to endorse or promote products derived from
+ * this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
-#ifndef WEBKIT_GLUE_SEARCHABLE_FORM_DATA_H__
-#define WEBKIT_GLUE_SEARCHABLE_FORM_DATA_H__
+#ifndef WebSearchableFormData_h
+#define WebSearchableFormData_h
-#include <string>
+#include "WebString.h"
+#include "WebURL.h"
-#include "googleurl/src/gurl.h"
-
namespace WebKit {
class WebForm;
-}
-namespace webkit_glue {
+// SearchableFormData encapsulates a URL and encoding of an INPUT field that
+// corresponds to a searchable form request.
+class WebSearchableFormData {
+public:
+ // If the provided form is suitable for automated searching, |m_url| and
+ // |m_encoding| are set appropriately. Otherwise |m_url| will be left
+ // invalid.
+ WebSearchableFormData(const WebForm&);
-// SearchableFormData encapsulates a URL and class name of an INPUT field
-// that correspond to a searchable form request.
-class SearchableFormData {
- public:
- // If form contains elements that constitutes a valid searchable form
- // request, a SearchableFormData is created and returned.
- static SearchableFormData* Create(const WebKit::WebForm& form);
+ // URL for the searchable form request.
+ const WebURL& url() const
+ {
+ return m_url;
+ }
- // URL for the searchable form request.
- const GURL& url() const { return url_; }
+ // Encoding used to encode the form parameters; never empty.
+ const WebString& encoding() const
+ {
+ return m_encoding;
+ }
- // Encoding used to encode the form parameters; never empty.
- const std::string& encoding() const { return encoding_; }
-
- private:
- SearchableFormData(const GURL& url, const std::string& encoding)
- : url_(url),
- encoding_(encoding) {
- }
-
- const GURL url_;
- const std::string encoding_;
-
- DISALLOW_COPY_AND_ASSIGN(SearchableFormData);
+private:
+ WebURL m_url;
+ WebString m_encoding;
};
-} // namespace webkit_glue
+} // namespace WebKit
-#endif // WEBKIT_GLUE_SEARCHABLE_FORM_H__
+#endif
« no previous file with comments | « chrome/renderer/render_view.cc ('k') | webkit/api/src/WebSearchableFormData.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698